==> nostr_relay-1.7.tar.gz: nostr_relay-1.7/nostr_relay/notifier.py <==
"""
notifier is a simple TCP server/client that broadcasts event ids to all connected clients
"""
import asyncio
import logging
from aionostr.event import Event


class NotifyServer:
    def __init__(self, port=6000):
        self.connections = {}
        self.port = port
        self.log = logging.getLogger("nostr_relay.notify:server")

    async def handle_notify(self, reader, writer):
        addr = writer.get_extra_info('peername')
        self.log.debug(addr)
        self.connections[addr] = writer

        while True:
            data = await reader.read(32)
            if not data:
                break
            self.log.debug("Broadcasting %s to %s connections", data.hex(), len(self.connections) - 1)

            for peer in self.connections.values():
                if peer != writer:
                    peer.write(data)
                    await peer.drain()
        del self.connections[addr]

    async def run(self):
        try:
            server = await asyncio.start_server(self.handle_notify, '127.0.0.1', self.port)
        except OSError:
            self.log.debug("could not start")
            return
        self.log.info("Starting notify server on port %s", self.port)
        async with server:
            await server.serve_forever()

    def start(self):
        return asyncio.create_task(self.run())


class NotifyClient:
    def __init__(self, storage, port=6000, address='127.0.0.1'):
        self.storage = storage
        self.writer = None
        self.port = port
        self.address = address
        self.log = logging.getLogger("nostr_relay.notify:client")

    async def notify(self, event: Event):
        self.log.debug("notifying about %s", event.id)
        self.writer.write(event.id_bytes)
        await self.writer.drain()

    async def connect(self):
        await asyncio.sleep(2)
        self.log.info("Connecting to notify server on port %s", self.port)
        reader, self.writer = await asyncio.open_connection(self.address, self.port)

        while True:
            data = await reader.read(32)
            if not data:
                break
            event = await self.storage.get_event(data.hex())
            if event:
                self.log.debug("Got %s", data.hex())
                self.storage.notify_all_connected(event)
        self.log.info("Closed")

    def start(self):
        return asyncio.create_task(self.connect())

==> nostr_relay-1.10.5.tar.gz: nostr_relay-1.10.5/nostr_relay/notifier.py <==
"""
notifier is a simple TCP server/client that broadcasts event ids to all connected clients
"""
import asyncio
import logging
from aionostr.event import Event


class NotifyServer:
    def __init__(self, port=6000):
        self.connections = {}
        self.port = port
        self.log = logging.getLogger("nostr_relay.notify:server")

    async def handle_notify(self, reader, writer):
        addr = writer.get_extra_info("peername")
        self.log.debug(addr)
        self.connections[addr] = writer

        while True:
            data = await reader.read(32)
            if not data:
                break
            self.log.debug(
                "Broadcasting %s to %s connections",
                data.hex(),
                len(self.connections) - 1,
            )

            for peer in self.connections.values():
                if peer != writer:
                    peer.write(data)
                    await peer.drain()
        del self.connections[addr]

    async def run(self):
        try:
            server = await asyncio.start_server(
                self.handle_notify, "127.0.0.1", self.port
            )
        except OSError:
            self.log.debug("could not start")
            return
        self.log.info("Starting notify server on port %s", self.port)
        async with server:
            await server.serve_forever()

    def start(self):
        return asyncio.create_task(self.run())


class NotifyClient:
    def __init__(self, storage, port=6000, address="127.0.0.1"):
        self.storage = storage
        self.writer = None
        self.port = port
        self.address = address
        self.log = logging.getLogger("nostr_relay.notify:client")

    async def notify(self, event: Event):
        self.log.debug("notifying about %s", event.id)
        self.writer.write(event.id_bytes)
        await self.writer.drain()

    async def connect(self):
        await asyncio.sleep(2)
        self.log.info("Connecting to notify server on port %s", self.port)
        reader, self.writer = await asyncio.open_connection(self.address, self.port)

        while True:
            data = await reader.read(32)
            if not data:
                break
            event = await self.storage.get_event(data.hex())
            if event:
                self.log.debug("Got %s", data.hex())
                self.storage.notify_all_connected(event)
        self.log.info("Closed")

    def start(self):
        return asyncio.create_task(self.connect())
